@@ -7,7 +7,8 @@
 #' snippet, statistics, status, suggestions, topicDetails}. Default:
 #' \code{contentDetails}.
 #' @param max_results Maximum number of items that should be returned. Integer.
-#' Optional. Can be between 0 and 50. Default is 50.
+#' Optional. Default is 50. Values over 50 will trigger multiple requests and
+#' may use additional API quota.
 #' @param page_token specific page in the result set that should be returned,
 #' optional
 #' @param region_code Character. Required. Has to be a ISO 3166-1 alpha-2 code
@@ -36,16 +37,27 @@ list_videos <- function(part = "contentDetails", max_results = 50,
                         page_token = NULL, hl = NULL, region_code = NULL,
                         video_category_id = NULL, ...) {
 
-  if (is.numeric(max_results) && (max_results < 0 || max_results > 50)) {
-    stop("max_results only takes a value between 0 and 50.")
+  if (max_results <= 0) {
+    stop("max_results must be a positive integer.")
   }
 
   querylist <- list(chart = "mostPopular", part = part,
-                    maxResults = max_results, pageToken = page_token, hl = hl,
+                    maxResults = min(max_results, 50), pageToken = page_token, hl = hl,
                     regionCode = region_code,
                     videoCategoryId = video_category_id)
 
   res <- tuber_GET("videos", querylist, ...)
+  items <- res$items
+  next_token <- res$nextPageToken
 
+  while (length(items) < max_results && !is.null(next_token)) {
+    querylist$pageToken <- next_token
+    querylist$maxResults <- min(50, max_results - length(items))
+    a_res <- tuber_GET("videos", querylist, ...)
+    items <- c(items, a_res$items)
+    next_token <- a_res$nextPageToken
+  }
+
+  res$items <- items
   res
 }
