@@ -100,9 +100,12 @@ yt_get_key <- function(decrypt = FALSE) {
       answer <- utils::askYesNo("Do you want to set YOUTUBE_KEY?")
       if (isTRUE(answer)) {
         api_key <- yt_set_key()
+        if (is.null(api_key)) {
+          return(invisible(NULL))
+        }
       }
     } else {
-      invisible(NULL)
+      return(invisible(NULL))
     }
   }
   if (!identical(api_key, "")) {
@@ -125,16 +128,26 @@ yt_set_key <- function(key = NULL, type = "api") {
   if (type == "api") {
     if (interactive() && is.null(key)) {
       key <- askpass("Please enter your YouTube API key")
-      stopifnot("YOUTUBE_KEY must be a character vector" = is.character(key))
+      if (is.null(key) || !is.character(key)) {
+        return(invisible(NULL))
+      }
+    } else if (is.null(key)) {
+      return(invisible(NULL))
     }
+    stopifnot("YOUTUBE_KEY must be a character vector" = is.character(key))
     Sys.setenv(YOUTUBE_KEY = key)
     message("YOUTUBE_KEY was stored in '.Renviron' and was invisibly returned")
   }
   if (type == "package") {
     if (interactive() && is.null(key)) {
       key <- askpass("Please enter your package key")
-      stopifnot("TUBER_KEY must be a character vector" = is.character(key))
+      if (is.null(key) || !is.character(key)) {
+        return(invisible(NULL))
+      }
+    } else if (is.null(key)) {
+      return(invisible(NULL))
     }
+    stopifnot("TUBER_KEY must be a character vector" = is.character(key))
     Sys.setenv(TUBER_KEY = key)
     message("TUBER_KEY was stored in '.Renviron' and was invisibly returned")
   }
@@ -165,6 +178,9 @@ is_testing <- function() {
 #' @return list
 
 tuber_GET <- function(path, query, auth = "token", ...) {
+  # Track quota usage
+  parts <- query$part %||% NULL
+  track_quota_usage(path, parts)
 
   if (auth == "token") {
     yt_check_token()
@@ -185,6 +201,26 @@ tuber_GET <- function(path, query, auth = "token", ...) {
     res <- req %>% resp_body_json()
   }
 
+  # Check for rate limiting and quota errors
+  if (exists("req") && !is.null(req$status_code)) {
+    if (req$status_code == 403) {
+      # Check if it's a quota error
+      error_content <- tryCatch({
+        if (auth == "token") content(req, as = "text") else httr2::resp_body_string(req)
+      }, error = function(e) "")
+      
+      if (grepl("quotaExceeded|dailyLimitExceeded", error_content)) {
+        quota_status <- yt_get_quota_usage()
+        stop("YouTube API quota exhausted. Used: ", quota_status$quota_used, "/", quota_status$quota_limit, 
+             ". Quota resets at: ", format(quota_status$reset_time, "%Y-%m-%d %H:%M:%S UTC"))
+      }
+    }
+    
+    if (req$status_code == 429) {
+      warning("Rate limited by YouTube API. Consider adding delays between requests.")
+    }
+  }
+
   tuber_check(req)
 
   res
