@@ -11,7 +11,7 @@
 #' `publishAt`.
 #' @param query Fields for `query` in `POST`
 #' @param ... Additional arguments to send to \code{\link{tuber_POST}} and
-#' therefore \code{\link{POST}}
+#' therefore \code{\link[httr]{POST}}
 #' @param open_url Should the video be opened using \code{\link{browseURL}}
 #'
 #' @note The information for `status` and `snippet` are at
@@ -22,7 +22,7 @@
 #' It identifies the properties that the write operation will set, this will be
 #' automatically detected by the names of `body`.
 #' See \url{https://developers.google.com/youtube/v3/docs/videos/insert#usage}
-#' @return A list of the response object from the \code{POST}, content,
+#' @return A list of the response object from the \code{\link[httr]{POST}}, content,
 #' and the URL of the uploaded
 #' @export
 #'
@@ -86,35 +86,52 @@ upload_video <- function(
   writeLines(body, metadata)
 
   body <- list(
-    metadata = upload_file(metadata, type = "application/json; charset=UTF-8"),
-    y = httr::upload_file(file))
+    metadata = httr::upload_file(metadata, type = "application/json; charset=UTF-8"),
+    y = httr::upload_file(file)
+  )
 
   yt_check_token()
 
-  req <- httr::POST("https://www.googleapis.com/upload/youtube/v3/videos",
-                    body = body, query = query,
-                    config(token = getOption("google_token")),
-                    ...)
+  headers <- c(
+    "Authorization" = paste("Bearer", getOption("google_token")), #$credentials$access_token),
+    "Content-Length" = file.size(file),
+    "Content-Type" = "application/json; charset=utf-8",
+    "X-Upload-Content-Length" = file.size(file),
+    "X-Upload-Content-Type" = mime::guess_type(file)
+  )
 
-  if (httr::status_code(req) > 300)  {
-    print(body)
-    print(paste0("File is: ", metadata))
-    cat(readLines(metadata))
-    cat("\n")
-    print(query)
-    print(httr::content(req)$error)
-    stop("Request was bad")
+  resumable_upload_url <- "https://www.googleapis.com/upload/youtube/v3/videos?uploadType=resumable&part=parts"
+  resumable_upload_req <- httr::POST(resumable_upload_url,
+                                     config(token = getOption("google_token")),
+                                     httr::add_headers(headers),
+                                     ...
+  )
+
+  if (httr::status_code(resumable_upload_req) != 200) {
+    stop("Failed to initiate resumable upload")
   }
 
-  tuber_check(req)
+  upload_url <- httr::headers(resumable_upload_req)$`x-guploader-uploadid`
 
-  res <- content(req)
+  upload_req <- httr::PUT(upload_url,
+                          body = httr::upload_file(file),
+                          config(token = getOption("google_token")),
+                          ...
+  )
+
+  if (httr::status_code(upload_req) != 200) {
+    stop("Failed to upload video")
+  }
+
+  tuber_check(upload_req)
+
+  res <- content(upload_req)
   url <- paste0("https://www.youtube.com/watch?v=", res$id)
 
   if (open_url) {
     browseURL(url)
   }
 
-  list(request = req, content = res,
+  list(request = upload_req, content = res,
        url = url)
 }
